"""Create a table of marks given by each student for each question."""

__author__ = """Kayané Elmayan Robach"""
__email__ = 'kaya.robach@gmail.com'
__version__ = '0.3.0'

from .create_marks import conditionnal_proba
from .create_marks import complete_proba_matrix
from .create_marks import create_marks