"""Cluster the students and predict the cluster for a new student."""

__author__ = """Kayané Elmayan Robach"""
__email__ = 'kaya.robach@gmail.com'
__version__ = '0.3.0'

from .cluster_students import plot_clustering
from .cluster_students import creationDFClustering
from .cluster_students import optimal_n_clusters
from .cluster_students import similar_students
